@@ -1635,7 +1635,7 @@ class NcmClient:
                           max_test_concurrency=5, port=12865, size=None,
                           test_timeout=10, test_type="TCP Download", time=10):
         """
-        This operation creates a speed test using Netperf.
+        This method creates a speed test using Netperf.
 
         Usage Example:
         n.create_speed_test([12345])
@@ -1677,6 +1677,44 @@ class NcmClient:
         else:
             return ncm.text
 
+    def create_speed_test_mdm(self, router_id, account_id=None,
+                          host="netperf-west.bufferbloat.net",
+                          max_test_concurrency=5, port=12865, size=None,
+                          test_timeout=10, test_type="TCP Download", time=10):
+        """
+        This method creates a speed test using Netperf for all connected
+        modems by specifying a router_id. This is helpful when the desired
+        net_device_id(s) are not known
+
+        Usage Example:
+        n.create_speed_test_mdm(12345)
+
+        :param account_id: Account in which to create the speed_test record.
+        :param host: URL of Speedtest Server.
+        :param max_test_concurrency: Number of maximum simultaneous tests to server (1-50).
+        :param router_id: Router ID to test.
+        :param port: TCP port for test.
+        :param size: Number of bytes to transfer.
+        :param test_timeout: Test timeout in seconds.
+        :param test_type: TCP Download, TCP Upload, TCP Latency
+        :param time: Test time
+        :return:
+        """
+
+        net_devices = self.get_net_devices_for_router(router_id, connection_state='connected', is_asset=True)
+        net_device_ids = [int(x["id"]) for x in net_devices]
+        print(net_device_ids)
+        speed_test = self.create_speed_test(net_device_ids=net_device_ids,
+                                            account_id=account_id,
+                                            host=host,
+                                            max_test_concurrency=max_test_concurrency,
+                                            port=port,
+                                            size=size,
+                                            test_timeout=test_timeout,
+                                            test_type=test_type,
+                                            time=time)
+        return speed_test
+
     def get_speed_test(self, speed_test_id, **kwargs):
         """
         This method gets the status/results of a created speed test.
